summaryrefslogtreecommitdiffstats
path: root/kmail/objecttreeparser.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/objecttreeparser.h')
-rw-r--r--kmail/objecttreeparser.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmail/objecttreeparser.h b/kmail/objecttreeparser.h
index ad980eda..5cfe1d0e 100644
--- a/kmail/objecttreeparser.h
+++ b/kmail/objecttreeparser.h
@@ -151,7 +151,7 @@ namespace KMail {
mIncludeSignatures = include;
}
- // Controls whether Toltec invitations are displayed in their raw form or as a replacement text,
+ // Controls whether Toltec invitations are displayed in their raw form or as a tqreplacement text,
// which is used in processToltecMail().
void setShowRawToltecMail( bool showRawToltecMail ) { mShowRawToltecMail = showRawToltecMail; }
bool showRawToltecMail() const { return mShowRawToltecMail; }
@@ -171,7 +171,7 @@ namespace KMail {
/** Parse beginning at a given node and recursively parsing
the children of that node and it's next sibling. */
// Function is called internally by "parseMsg(KMMessage* msg)"
- // and it will be replaced once KMime is alive.
+ // and it will be tqreplaced once KMime is alive.
void parseObjectTree( partNode * node );
private:
@@ -193,7 +193,7 @@ namespace KMail {
* Setting this to false is useful for encapsulated messages, as we
* do not want the text in those to appear in the editor
*/
- // Function will be replaced once KMime is alive.
+ // Function will be tqreplaced once KMime is alive.
void insertAndParseNewChildNode( partNode & node,
const char * content,
const char * cntDesc,
@@ -252,11 +252,11 @@ namespace KMail {
*/
bool processToltecMail( partNode * node );
- /** Checks whether @p str contains external references. To be precise,
- we only check whether @p str contains 'xxx="http[s]:' where xxx is
+ /** Checks whether @p str tqcontains external references. To be precise,
+ we only check whether @p str tqcontains 'xxx="http[s]:' where xxx is
not href. Obfuscated external references are ignored on purpose.
*/
- static bool containsExternalReferences( const TQCString & str );
+ static bool tqcontainsExternalReferences( const TQCString & str );
public:// (during refactoring)